# -*- coding: utf-8 -*-
"""pipeline_analyse_de_sentiments.ipynb

Automatically generated by Colab.

Original file is located at
    https://colab.research.google.com/drive/1xZQuXxVy4fh38McohChFgNkl1T4YQKbb

Projet : Analyse de sentiment de texte avec BERT pré-entraîné

🎯 Objectif :

Utiliser un modèle pré-entraîné (comme distilbert-base-uncased-finetuned-sst-2-english) pour analyser le sentiment (positif/négatif) d’un texte. Tu apprendras à :

- Charger un modèle via Hugging Face

- Créer un petit dataset perso

- Lancer une prédiction

- Optionnel : fine-tuner sur ton propre jeu de données

Liens :

https://huggingface.co/docs/transformers/main_classes/pipelines
"""

!pip install transformers datasets torch

from transformers import pipeline

# Crée un pipeline d’analyse de sentiment
sentiment_analyzer = pipeline("sentiment-analysis")

# Exemple
result = sentiment_analyzer("J'adore ce film, il est fantastique !")
print(result)  # [{'label': 'POSITIVE', 'score': 0.999...}]

# Commented out IPython magic to ensure Python compatibility.
# %%writefile avis.txt
# Ce produit est génial !
# Je déteste ce service.
# Moyen, pas terrible.
# J’ai été agréablement surpris.
#

!cat avis.txt

with open("avis.txt", "r", encoding="utf-8") as f:
    lines = f.readlines()

for line in lines:
    print(line.strip(), "→", sentiment_analyzer(line)[0])

import pandas as pd

results = [{"text": line.strip(), **sentiment_analyzer(line)[0]} for line in lines]
df = pd.DataFrame(results)
print(df)